@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2016-2018 Montel Laurent <montel@kde.org>
+   Copyright (C) 2016-2019 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -28,7 +28,7 @@ ImportImapSettingFinishPage::ImportImapSettingFinishPage(QWidget *parent)
 {
     QVBoxLayout *mainlayout = new QVBoxLayout(this);
     mainlayout->setObjectName(QStringLiteral("mainlayout"));
-    mainlayout->setMargin(0);
+    mainlayout->setContentsMargins(0, 0, 0, 0);
 
     QLabel *label = new QLabel(i18n("IMAP settings were imported:"), this);
     label->setObjectName(QStringLiteral("label"));
