@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2016-2018 Montel Laurent <montel@kde.org>
+   Copyright (C) 2016-2019 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -30,7 +30,7 @@ ImportImapSettingProgressPage::ImportImapSettingProgressPage(QWidget *parent)
 {
     QVBoxLayout *mainLayout = new QVBoxLayout(this);
     mainLayout->setObjectName(QStringLiteral("mainlayout"));
-    mainLayout->setMargin(0);
+    mainLayout->setContentsMargins(0, 0, 0, 0);
     mProgressTextEdit = new QTextEdit(this);
     mProgressTextEdit->setObjectName(QStringLiteral("textedit"));
     mProgressTextEdit->setReadOnly(true);
